package com.jiuqi.db;

import java.sql.Savepoint;
import java.util.Map;
import java.sql.SQLWarning;
import java.sql.DatabaseMetaData;
import java.sql.CallableStatement;
import java.sql.PreparedStatement;
import java.sql.Statement;
import java.sql.SQLException;
import java.sql.Connection;

public class DBConnection implements Connection
{
    private Connection conn;
    private boolean isTransManaged;
    
    public DBConnection(final IConnection aConn) {
        this.isTransManaged = false;
        this.isTransManaged = false;
        this.conn = aConn.getConnection();
        DBTrace.createConnection(this);
    }
    
    public DBConnection(final Connection aConn) {
        this.isTransManaged = false;
        this.isTransManaged = false;
        this.conn = aConn;
        DBTrace.createConnection(this);
    }
    
    public DBConnection(final IConnection aConn, final boolean transManaged, final boolean autoCommit) throws SQLException {
        this.isTransManaged = false;
        this.isTransManaged = transManaged;
        (this.conn = aConn.getConnection()).setAutoCommit(autoCommit);
        DBTrace.createConnection(this);
    }
    
    public DBConnection(final Connection aConn, final boolean transManaged, final boolean autoCommit) throws SQLException {
        this.isTransManaged = false;
        this.isTransManaged = transManaged;
        (this.conn = aConn).setAutoCommit(autoCommit);
        DBTrace.createConnection(this);
    }
    
    public Statement createStatement() throws SQLException {
        final Statement stmt = this.conn.createStatement();
        return new DBStatement(stmt, this);
    }
    
    public PreparedStatement prepareStatement(final String string) throws SQLException {
        final PreparedStatement stmt = this.conn.prepareStatement(string);
        return new DBPreparedStatement(stmt, this);
    }
    
    public CallableStatement prepareCall(final String string) throws SQLException {
        return this.conn.prepareCall(string);
    }
    
    public String nativeSQL(final String string) throws SQLException {
        return this.conn.nativeSQL(string);
    }
    
    public void setAutoCommit(final boolean boolean0) throws SQLException {
        if (this.isTransManaged) {
            return;
        }
        this.conn.setAutoCommit(boolean0);
    }
    
    public boolean getAutoCommit() throws SQLException {
        return this.conn.getAutoCommit();
    }
    
    public void commit() throws SQLException {
        if (this.isTransManaged) {
            return;
        }
        this.conn.commit();
    }
    
    public void rollback() throws SQLException {
        if (this.isTransManaged) {
            return;
        }
        this.conn.rollback();
    }
    
    public void close() throws SQLException {
        DBTrace.closeConnection(this);
        if (this.isTransManaged) {
            return;
        }
        this.conn.close();
    }
    
    public boolean isClosed() throws SQLException {
        return this.conn.isClosed();
    }
    
    public DatabaseMetaData getMetaData() throws SQLException {
        return this.conn.getMetaData();
    }
    
    public void setReadOnly(final boolean boolean0) throws SQLException {
        this.conn.setReadOnly(boolean0);
    }
    
    public boolean isReadOnly() throws SQLException {
        return this.conn.isReadOnly();
    }
    
    public void setCatalog(final String string) throws SQLException {
        this.conn.setCatalog(string);
    }
    
    public String getCatalog() throws SQLException {
        return this.conn.getCatalog();
    }
    
    public void setTransactionIsolation(final int int0) throws SQLException {
        this.conn.setTransactionIsolation(int0);
    }
    
    public int getTransactionIsolation() throws SQLException {
        return this.conn.getTransactionIsolation();
    }
    
    public SQLWarning getWarnings() throws SQLException {
        return this.conn.getWarnings();
    }
    
    public void clearWarnings() throws SQLException {
        this.conn.clearWarnings();
    }
    
    public Statement createStatement(final int int0, final int int1) throws SQLException {
        final Statement stmt = this.conn.createStatement(int0, int1);
        return new DBStatement(stmt, this.conn);
    }
    
    public PreparedStatement prepareStatement(final String string, final int int1, final int int2) throws SQLException {
        final PreparedStatement stmt = this.conn.prepareStatement(string, int1, int2);
        return new DBPreparedStatement(stmt, this);
    }
    
    public CallableStatement prepareCall(final String string, final int int1, final int int2) throws SQLException {
        return this.conn.prepareCall(string, int1, int2);
    }
    
    public Map getTypeMap() throws SQLException {
        return this.conn.getTypeMap();
    }
    
    public void setTypeMap(final Map map) throws SQLException {
        this.conn.setTypeMap(map);
    }
    
    public void setHoldability(final int holdability) throws SQLException {
        this.conn.setHoldability(holdability);
    }
    
    public int getHoldability() throws SQLException {
        return this.conn.getHoldability();
    }
    
    public Savepoint setSavepoint() throws SQLException {
        return this.conn.setSavepoint();
    }
    
    public Savepoint setSavepoint(final String name) throws SQLException {
        return this.conn.setSavepoint(name);
    }
    
    public void rollback(final Savepoint savepoint) throws SQLException {
        this.conn.rollback(savepoint);
    }
    
    public void releaseSavepoint(final Savepoint savepoint) throws SQLException {
        this.conn.releaseSavepoint(savepoint);
    }
    
    public Statement createStatement(final int resultSetType, final int resultSetConcurrency, final int resultSetHoldability) throws SQLException {
        final Statement stmt = this.conn.createStatement(resultSetType, resultSetConcurrency);
        return new DBStatement(stmt, this);
    }
    
    public PreparedStatement prepareStatement(final String sql, final int resultSetType, final int resultSetConcurrency, final int resultSetHoldability) throws SQLException {
        final PreparedStatement stmt = this.conn.prepareStatement(sql, resultSetType, resultSetConcurrency, resultSetHoldability);
        return new DBPreparedStatement(stmt, this);
    }
    
    public CallableStatement prepareCall(final String sql, final int resultSetType, final int resultSetConcurrency, final int resultSetHoldability) throws SQLException {
        return this.conn.prepareCall(sql, resultSetType, resultSetConcurrency, resultSetHoldability);
    }
    
    public PreparedStatement prepareStatement(final String sql, final int autoGeneratedKeys) throws SQLException {
        final PreparedStatement stmt = this.conn.prepareStatement(sql, autoGeneratedKeys);
        return new DBPreparedStatement(stmt, this);
    }
    
    public PreparedStatement prepareStatement(final String sql, final int[] columnIndexes) throws SQLException {
        final PreparedStatement stmt = this.conn.prepareStatement(sql, columnIndexes);
        return new DBPreparedStatement(stmt, this);
    }
    
    public PreparedStatement prepareStatement(final String sql, final String[] columnNames) throws SQLException {
        final PreparedStatement stmt = this.conn.prepareStatement(sql, columnNames);
        return new DBPreparedStatement(stmt, this);
    }
}
